Some links:
* https://docs.djangoproject.com/en/5.0/ref/files/storage/
* https://docs.python.org/3/library/io.html
* https://www.postgresql.org/docs/16/lo-funcs.html
* https://www.postgresql.org/docs/current/lo-interfaces.html
